@@ -85,7 +85,7 @@ class KinesisAnalyticsClient(BaseClient):
         *,
         ApplicationName: str,
         CurrentApplicationVersionId: int,
-        CloudWatchLoggingOption: "CloudWatchLoggingOptionTypeDef"
+        CloudWatchLoggingOption: CloudWatchLoggingOptionTypeDef
     ) -> Dict[str, Any]:
         """
         .
@@ -95,7 +95,7 @@ class KinesisAnalyticsClient(BaseClient):
         """
 
     def add_application_input(
-        self, *, ApplicationName: str, CurrentApplicationVersionId: int, Input: "InputTypeDef"
+        self, *, ApplicationName: str, CurrentApplicationVersionId: int, Input: InputTypeDef
     ) -> Dict[str, Any]:
         """
         .
@@ -110,7 +110,7 @@ class KinesisAnalyticsClient(BaseClient):
         ApplicationName: str,
         CurrentApplicationVersionId: int,
         InputId: str,
-        InputProcessingConfiguration: "InputProcessingConfigurationTypeDef"
+        InputProcessingConfiguration: InputProcessingConfigurationTypeDef
     ) -> Dict[str, Any]:
         """
         .
@@ -120,7 +120,7 @@ class KinesisAnalyticsClient(BaseClient):
         """
 
     def add_application_output(
-        self, *, ApplicationName: str, CurrentApplicationVersionId: int, Output: "OutputTypeDef"
+        self, *, ApplicationName: str, CurrentApplicationVersionId: int, Output: OutputTypeDef
     ) -> Dict[str, Any]:
         """
         .
@@ -134,7 +134,7 @@ class KinesisAnalyticsClient(BaseClient):
         *,
         ApplicationName: str,
         CurrentApplicationVersionId: int,
-        ReferenceDataSource: "ReferenceDataSourceTypeDef"
+        ReferenceDataSource: ReferenceDataSourceTypeDef
     ) -> Dict[str, Any]:
         """
         .
@@ -156,11 +156,11 @@ class KinesisAnalyticsClient(BaseClient):
         *,
         ApplicationName: str,
         ApplicationDescription: str = ...,
-        Inputs: Sequence["InputTypeDef"] = ...,
-        Outputs: Sequence["OutputTypeDef"] = ...,
-        CloudWatchLoggingOptions: Sequence["CloudWatchLoggingOptionTypeDef"] = ...,
+        Inputs: Sequence[InputTypeDef] = ...,
+        Outputs: Sequence[OutputTypeDef] = ...,
+        CloudWatchLoggingOptions: Sequence[CloudWatchLoggingOptionTypeDef] = ...,
         ApplicationCode: str = ...,
-        Tags: Sequence["TagTypeDef"] = ...
+        Tags: Sequence[TagTypeDef] = ...
     ) -> CreateApplicationResponseTypeDef:
         """
         .
@@ -236,9 +236,9 @@ class KinesisAnalyticsClient(BaseClient):
         *,
         ResourceARN: str = ...,
         RoleARN: str = ...,
-        InputStartingPositionConfiguration: "InputStartingPositionConfigurationTypeDef" = ...,
-        S3Configuration: "S3ConfigurationTypeDef" = ...,
-        InputProcessingConfiguration: "InputProcessingConfigurationTypeDef" = ...
+        InputStartingPositionConfiguration: InputStartingPositionConfigurationTypeDef = ...,
+        S3Configuration: S3ConfigurationTypeDef = ...,
+        InputProcessingConfiguration: InputProcessingConfigurationTypeDef = ...
     ) -> DiscoverInputSchemaResponseTypeDef:
         """
         .
@@ -280,7 +280,7 @@ class KinesisAnalyticsClient(BaseClient):
         """
 
     def start_application(
-        self, *, ApplicationName: str, InputConfigurations: Sequence["InputConfigurationTypeDef"]
+        self, *, ApplicationName: str, InputConfigurations: Sequence[InputConfigurationTypeDef]
     ) -> Dict[str, Any]:
         """
         .
@@ -297,7 +297,7 @@ class KinesisAnalyticsClient(BaseClient):
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_kinesisanalytics/client/#stop_application)
         """
 
-    def tag_resource(self, *, ResourceARN: str, Tags: Sequence["TagTypeDef"]) -> Dict[str, Any]:
+    def tag_resource(self, *, ResourceARN: str, Tags: Sequence[TagTypeDef]) -> Dict[str, Any]:
         """
         Adds one or more key-value tags to a Kinesis Analytics application.
 
@@ -318,7 +318,7 @@ class KinesisAnalyticsClient(BaseClient):
         *,
         ApplicationName: str,
         CurrentApplicationVersionId: int,
-        ApplicationUpdate: "ApplicationUpdateTypeDef"
+        ApplicationUpdate: ApplicationUpdateTypeDef
     ) -> Dict[str, Any]:
         """
         .
