@@ -6,9 +6,9 @@ Type annotations for kinesisanalytics service type definitions.
 Usage::
 
     ```python
-    from mypy_boto3_kinesisanalytics.type_defs import AddApplicationCloudWatchLoggingOptionRequestRequestTypeDef
+    from mypy_boto3_kinesisanalytics.type_defs import CloudWatchLoggingOptionTypeDef
 
-    data: AddApplicationCloudWatchLoggingOptionRequestRequestTypeDef = {...}
+    data: CloudWatchLoggingOptionTypeDef = {...}
     ```
 """
 import sys
@@ -24,54 +24,38 @@ else:
 
 
 __all__ = (
-    "AddApplicationCloudWatchLoggingOptionRequestRequestTypeDef",
-    "AddApplicationInputProcessingConfigurationRequestRequestTypeDef",
-    "AddApplicationInputRequestRequestTypeDef",
-    "AddApplicationOutputRequestRequestTypeDef",
-    "AddApplicationReferenceDataSourceRequestRequestTypeDef",
-    "ApplicationDetailTypeDef",
-    "ApplicationSummaryTypeDef",
-    "ApplicationUpdateTypeDef",
-    "CSVMappingParametersTypeDef",
-    "CloudWatchLoggingOptionDescriptionTypeDef",
     "CloudWatchLoggingOptionTypeDef",
+    "CloudWatchLoggingOptionDescriptionTypeDef",
+    "ApplicationSummaryTypeDef",
     "CloudWatchLoggingOptionUpdateTypeDef",
-    "CreateApplicationRequestRequestTypeDef",
-    "CreateApplicationResponseTypeDef",
+    "CSVMappingParametersTypeDef",
+    "TagTypeDef",
+    "ResponseMetadataTypeDef",
     "DeleteApplicationCloudWatchLoggingOptionRequestRequestTypeDef",
     "DeleteApplicationInputProcessingConfigurationRequestRequestTypeDef",
     "DeleteApplicationOutputRequestRequestTypeDef",
     "DeleteApplicationReferenceDataSourceRequestRequestTypeDef",
     "DeleteApplicationRequestRequestTypeDef",
     "DescribeApplicationRequestRequestTypeDef",
-    "DescribeApplicationResponseTypeDef",
     "DestinationSchemaTypeDef",
-    "DiscoverInputSchemaRequestRequestTypeDef",
-    "DiscoverInputSchemaResponseTypeDef",
-    "InputConfigurationTypeDef",
-    "InputDescriptionTypeDef",
+    "InputStartingPositionConfigurationTypeDef",
+    "S3ConfigurationTypeDef",
+    "InputParallelismTypeDef",
+    "KinesisFirehoseInputDescriptionTypeDef",
+    "KinesisStreamsInputDescriptionTypeDef",
     "InputLambdaProcessorDescriptionTypeDef",
     "InputLambdaProcessorTypeDef",
     "InputLambdaProcessorUpdateTypeDef",
-    "InputParallelismTypeDef",
     "InputParallelismUpdateTypeDef",
-    "InputProcessingConfigurationDescriptionTypeDef",
-    "InputProcessingConfigurationTypeDef",
-    "InputProcessingConfigurationUpdateTypeDef",
-    "InputSchemaUpdateTypeDef",
-    "InputStartingPositionConfigurationTypeDef",
-    "InputTypeDef",
-    "InputUpdateTypeDef",
-    "JSONMappingParametersTypeDef",
-    "KinesisFirehoseInputDescriptionTypeDef",
+    "RecordColumnTypeDef",
     "KinesisFirehoseInputTypeDef",
+    "KinesisStreamsInputTypeDef",
     "KinesisFirehoseInputUpdateTypeDef",
+    "KinesisStreamsInputUpdateTypeDef",
+    "JSONMappingParametersTypeDef",
     "KinesisFirehoseOutputDescriptionTypeDef",
     "KinesisFirehoseOutputTypeDef",
     "KinesisFirehoseOutputUpdateTypeDef",
-    "KinesisStreamsInputDescriptionTypeDef",
-    "KinesisStreamsInputTypeDef",
-    "KinesisStreamsInputUpdateTypeDef",
     "KinesisStreamsOutputDescriptionTypeDef",
     "KinesisStreamsOutputTypeDef",
     "KinesisStreamsOutputUpdateTypeDef",
@@ -79,135 +63,53 @@ __all__ = (
     "LambdaOutputTypeDef",
     "LambdaOutputUpdateTypeDef",
     "ListApplicationsRequestRequestTypeDef",
-    "ListApplicationsResponseTypeDef",
     "ListTagsForResourceRequestRequestTypeDef",
+    "S3ReferenceDataSourceDescriptionTypeDef",
+    "S3ReferenceDataSourceTypeDef",
+    "S3ReferenceDataSourceUpdateTypeDef",
+    "StopApplicationRequestRequestTypeDef",
+    "UntagResourceRequestRequestTypeDef",
+    "AddApplicationCloudWatchLoggingOptionRequestRequestTypeDef",
+    "TagResourceRequestRequestTypeDef",
+    "CreateApplicationResponseTypeDef",
+    "ListApplicationsResponseTypeDef",
     "ListTagsForResourceResponseTypeDef",
+    "InputConfigurationTypeDef",
+    "InputProcessingConfigurationDescriptionTypeDef",
+    "InputProcessingConfigurationTypeDef",
+    "InputProcessingConfigurationUpdateTypeDef",
     "MappingParametersTypeDef",
     "OutputDescriptionTypeDef",
     "OutputTypeDef",
     "OutputUpdateTypeDef",
-    "RecordColumnTypeDef",
+    "StartApplicationRequestRequestTypeDef",
+    "AddApplicationInputProcessingConfigurationRequestRequestTypeDef",
+    "DiscoverInputSchemaRequestRequestTypeDef",
     "RecordFormatTypeDef",
+    "AddApplicationOutputRequestRequestTypeDef",
+    "InputSchemaUpdateTypeDef",
+    "SourceSchemaTypeDef",
+    "InputUpdateTypeDef",
+    "DiscoverInputSchemaResponseTypeDef",
+    "InputDescriptionTypeDef",
+    "InputTypeDef",
     "ReferenceDataSourceDescriptionTypeDef",
     "ReferenceDataSourceTypeDef",
     "ReferenceDataSourceUpdateTypeDef",
-    "ResponseMetadataTypeDef",
-    "S3ConfigurationTypeDef",
-    "S3ReferenceDataSourceDescriptionTypeDef",
-    "S3ReferenceDataSourceTypeDef",
-    "S3ReferenceDataSourceUpdateTypeDef",
-    "SourceSchemaTypeDef",
-    "StartApplicationRequestRequestTypeDef",
-    "StopApplicationRequestRequestTypeDef",
-    "TagResourceRequestRequestTypeDef",
-    "TagTypeDef",
-    "UntagResourceRequestRequestTypeDef",
+    "AddApplicationInputRequestRequestTypeDef",
+    "CreateApplicationRequestRequestTypeDef",
+    "ApplicationDetailTypeDef",
+    "AddApplicationReferenceDataSourceRequestRequestTypeDef",
+    "ApplicationUpdateTypeDef",
+    "DescribeApplicationResponseTypeDef",
     "UpdateApplicationRequestRequestTypeDef",
 )
 
-AddApplicationCloudWatchLoggingOptionRequestRequestTypeDef = TypedDict(
-    "AddApplicationCloudWatchLoggingOptionRequestRequestTypeDef",
+CloudWatchLoggingOptionTypeDef = TypedDict(
+    "CloudWatchLoggingOptionTypeDef",
     {
-        "ApplicationName": str,
-        "CurrentApplicationVersionId": int,
-        "CloudWatchLoggingOption": "CloudWatchLoggingOptionTypeDef",
-    },
-)
-
-AddApplicationInputProcessingConfigurationRequestRequestTypeDef = TypedDict(
-    "AddApplicationInputProcessingConfigurationRequestRequestTypeDef",
-    {
-        "ApplicationName": str,
-        "CurrentApplicationVersionId": int,
-        "InputId": str,
-        "InputProcessingConfiguration": "InputProcessingConfigurationTypeDef",
-    },
-)
-
-AddApplicationInputRequestRequestTypeDef = TypedDict(
-    "AddApplicationInputRequestRequestTypeDef",
-    {
-        "ApplicationName": str,
-        "CurrentApplicationVersionId": int,
-        "Input": "InputTypeDef",
-    },
-)
-
-AddApplicationOutputRequestRequestTypeDef = TypedDict(
-    "AddApplicationOutputRequestRequestTypeDef",
-    {
-        "ApplicationName": str,
-        "CurrentApplicationVersionId": int,
-        "Output": "OutputTypeDef",
-    },
-)
-
-AddApplicationReferenceDataSourceRequestRequestTypeDef = TypedDict(
-    "AddApplicationReferenceDataSourceRequestRequestTypeDef",
-    {
-        "ApplicationName": str,
-        "CurrentApplicationVersionId": int,
-        "ReferenceDataSource": "ReferenceDataSourceTypeDef",
-    },
-)
-
-_RequiredApplicationDetailTypeDef = TypedDict(
-    "_RequiredApplicationDetailTypeDef",
-    {
-        "ApplicationName": str,
-        "ApplicationARN": str,
-        "ApplicationStatus": ApplicationStatusType,
-        "ApplicationVersionId": int,
-    },
-)
-_OptionalApplicationDetailTypeDef = TypedDict(
-    "_OptionalApplicationDetailTypeDef",
-    {
-        "ApplicationDescription": str,
-        "CreateTimestamp": datetime,
-        "LastUpdateTimestamp": datetime,
-        "InputDescriptions": List["InputDescriptionTypeDef"],
-        "OutputDescriptions": List["OutputDescriptionTypeDef"],
-        "ReferenceDataSourceDescriptions": List["ReferenceDataSourceDescriptionTypeDef"],
-        "CloudWatchLoggingOptionDescriptions": List["CloudWatchLoggingOptionDescriptionTypeDef"],
-        "ApplicationCode": str,
-    },
-    total=False,
-)
-
-
-class ApplicationDetailTypeDef(
-    _RequiredApplicationDetailTypeDef, _OptionalApplicationDetailTypeDef
-):
-    pass
-
-
-ApplicationSummaryTypeDef = TypedDict(
-    "ApplicationSummaryTypeDef",
-    {
-        "ApplicationName": str,
-        "ApplicationARN": str,
-        "ApplicationStatus": ApplicationStatusType,
-    },
-)
-
-ApplicationUpdateTypeDef = TypedDict(
-    "ApplicationUpdateTypeDef",
-    {
-        "InputUpdates": Sequence["InputUpdateTypeDef"],
-        "ApplicationCodeUpdate": str,
-        "OutputUpdates": Sequence["OutputUpdateTypeDef"],
-        "ReferenceDataSourceUpdates": Sequence["ReferenceDataSourceUpdateTypeDef"],
-        "CloudWatchLoggingOptionUpdates": Sequence["CloudWatchLoggingOptionUpdateTypeDef"],
-    },
-    total=False,
-)
-
-CSVMappingParametersTypeDef = TypedDict(
-    "CSVMappingParametersTypeDef",
-    {
-        "RecordRowDelimiter": str,
-        "RecordColumnDelimiter": str,
+        "LogStreamARN": str,
+        "RoleARN": str,
     },
 )
 
@@ -234,11 +136,12 @@ class CloudWatchLoggingOptionDescriptionTypeDef(
     pass
 
 
-CloudWatchLoggingOptionTypeDef = TypedDict(
-    "CloudWatchLoggingOptionTypeDef",
+ApplicationSummaryTypeDef = TypedDict(
+    "ApplicationSummaryTypeDef",
     {
-        "LogStreamARN": str,
-        "RoleARN": str,
+        "ApplicationName": str,
+        "ApplicationARN": str,
+        "ApplicationStatus": ApplicationStatusType,
     },
 )
 
@@ -264,37 +167,41 @@ class CloudWatchLoggingOptionUpdateTypeDef(
     pass
 
 
-_RequiredCreateApplicationRequestRequestTypeDef = TypedDict(
-    "_RequiredCreateApplicationRequestRequestTypeDef",
+CSVMappingParametersTypeDef = TypedDict(
+    "CSVMappingParametersTypeDef",
     {
-        "ApplicationName": str,
+        "RecordRowDelimiter": str,
+        "RecordColumnDelimiter": str,
     },
 )
-_OptionalCreateApplicationRequestRequestTypeDef = TypedDict(
-    "_OptionalCreateApplicationRequestRequestTypeDef",
+
+_RequiredTagTypeDef = TypedDict(
+    "_RequiredTagTypeDef",
     {
-        "ApplicationDescription": str,
-        "Inputs": Sequence["InputTypeDef"],
-        "Outputs": Sequence["OutputTypeDef"],
-        "CloudWatchLoggingOptions": Sequence["CloudWatchLoggingOptionTypeDef"],
-        "ApplicationCode": str,
-        "Tags": Sequence["TagTypeDef"],
+        "Key": str,
+    },
+)
+_OptionalTagTypeDef = TypedDict(
+    "_OptionalTagTypeDef",
+    {
+        "Value": str,
     },
     total=False,
 )
 
 
-class CreateApplicationRequestRequestTypeDef(
-    _RequiredCreateApplicationRequestRequestTypeDef, _OptionalCreateApplicationRequestRequestTypeDef
-):
+class TagTypeDef(_RequiredTagTypeDef, _OptionalTagTypeDef):
     pass
 
 
-CreateApplicationResponseTypeDef = TypedDict(
-    "CreateApplicationResponseTypeDef",
+ResponseMetadataTypeDef = TypedDict(
+    "ResponseMetadataTypeDef",
     {
-        "ApplicationSummary": "ApplicationSummaryTypeDef",
-        "ResponseMetadata": "ResponseMetadataTypeDef",
+        "RequestId": str,
+        "HostId": str,
+        "HTTPStatusCode": int,
+        "HTTPHeaders": Dict[str, str],
+        "RetryAttempts": int,
     },
 )
 
@@ -349,14 +256,6 @@ DescribeApplicationRequestRequestTypeDef = TypedDict(
     },
 )
 
-DescribeApplicationResponseTypeDef = TypedDict(
-    "DescribeApplicationResponseTypeDef",
-    {
-        "ApplicationDetail": "ApplicationDetailTypeDef",
-        "ResponseMetadata": "ResponseMetadataTypeDef",
-    },
-)
-
 DestinationSchemaTypeDef = TypedDict(
     "DestinationSchemaTypeDef",
     {
@@ -364,49 +263,45 @@ DestinationSchemaTypeDef = TypedDict(
     },
 )
 
-DiscoverInputSchemaRequestRequestTypeDef = TypedDict(
-    "DiscoverInputSchemaRequestRequestTypeDef",
+InputStartingPositionConfigurationTypeDef = TypedDict(
+    "InputStartingPositionConfigurationTypeDef",
     {
-        "ResourceARN": str,
-        "RoleARN": str,
-        "InputStartingPositionConfiguration": "InputStartingPositionConfigurationTypeDef",
-        "S3Configuration": "S3ConfigurationTypeDef",
-        "InputProcessingConfiguration": "InputProcessingConfigurationTypeDef",
+        "InputStartingPosition": InputStartingPositionType,
     },
     total=False,
 )
 
-DiscoverInputSchemaResponseTypeDef = TypedDict(
-    "DiscoverInputSchemaResponseTypeDef",
+S3ConfigurationTypeDef = TypedDict(
+    "S3ConfigurationTypeDef",
     {
-        "InputSchema": "SourceSchemaTypeDef",
-        "ParsedInputRecords": List[List[str]],
-        "ProcessedInputRecords": List[str],
-        "RawInputRecords": List[str],
-        "ResponseMetadata": "ResponseMetadataTypeDef",
+        "RoleARN": str,
+        "BucketARN": str,
+        "FileKey": str,
     },
 )
 
-InputConfigurationTypeDef = TypedDict(
-    "InputConfigurationTypeDef",
+InputParallelismTypeDef = TypedDict(
+    "InputParallelismTypeDef",
     {
-        "Id": str,
-        "InputStartingPositionConfiguration": "InputStartingPositionConfigurationTypeDef",
+        "Count": int,
     },
+    total=False,
 )
 
-InputDescriptionTypeDef = TypedDict(
-    "InputDescriptionTypeDef",
+KinesisFirehoseInputDescriptionTypeDef = TypedDict(
+    "KinesisFirehoseInputDescriptionTypeDef",
     {
-        "InputId": str,
-        "NamePrefix": str,
-        "InAppStreamNames": List[str],
-        "InputProcessingConfigurationDescription": "InputProcessingConfigurationDescriptionTypeDef",
-        "KinesisStreamsInputDescription": "KinesisStreamsInputDescriptionTypeDef",
-        "KinesisFirehoseInputDescription": "KinesisFirehoseInputDescriptionTypeDef",
-        "InputSchema": "SourceSchemaTypeDef",
-        "InputParallelism": "InputParallelismTypeDef",
-        "InputStartingPositionConfiguration": "InputStartingPositionConfigurationTypeDef",
+        "ResourceARN": str,
+        "RoleARN": str,
+    },
+    total=False,
+)
+
+KinesisStreamsInputDescriptionTypeDef = TypedDict(
+    "KinesisStreamsInputDescriptionTypeDef",
+    {
+        "ResourceARN": str,
+        "RoleARN": str,
     },
     total=False,
 )
@@ -437,14 +332,6 @@ InputLambdaProcessorUpdateTypeDef = TypedDict(
     total=False,
 )
 
-InputParallelismTypeDef = TypedDict(
-    "InputParallelismTypeDef",
-    {
-        "Count": int,
-    },
-    total=False,
-)
-
 InputParallelismUpdateTypeDef = TypedDict(
     "InputParallelismUpdateTypeDef",
     {
@@ -453,111 +340,36 @@ InputParallelismUpdateTypeDef = TypedDict(
     total=False,
 )
 
-InputProcessingConfigurationDescriptionTypeDef = TypedDict(
-    "InputProcessingConfigurationDescriptionTypeDef",
+_RequiredRecordColumnTypeDef = TypedDict(
+    "_RequiredRecordColumnTypeDef",
     {
-        "InputLambdaProcessorDescription": "InputLambdaProcessorDescriptionTypeDef",
-    },
-    total=False,
-)
-
-InputProcessingConfigurationTypeDef = TypedDict(
-    "InputProcessingConfigurationTypeDef",
-    {
-        "InputLambdaProcessor": "InputLambdaProcessorTypeDef",
+        "Name": str,
+        "SqlType": str,
     },
 )
-
-InputProcessingConfigurationUpdateTypeDef = TypedDict(
-    "InputProcessingConfigurationUpdateTypeDef",
+_OptionalRecordColumnTypeDef = TypedDict(
+    "_OptionalRecordColumnTypeDef",
     {
-        "InputLambdaProcessorUpdate": "InputLambdaProcessorUpdateTypeDef",
-    },
-)
-
-InputSchemaUpdateTypeDef = TypedDict(
-    "InputSchemaUpdateTypeDef",
-    {
-        "RecordFormatUpdate": "RecordFormatTypeDef",
-        "RecordEncodingUpdate": str,
-        "RecordColumnUpdates": Sequence["RecordColumnTypeDef"],
-    },
-    total=False,
-)
-
-InputStartingPositionConfigurationTypeDef = TypedDict(
-    "InputStartingPositionConfigurationTypeDef",
-    {
-        "InputStartingPosition": InputStartingPositionType,
-    },
-    total=False,
-)
-
-_RequiredInputTypeDef = TypedDict(
-    "_RequiredInputTypeDef",
-    {
-        "NamePrefix": str,
-        "InputSchema": "SourceSchemaTypeDef",
-    },
-)
-_OptionalInputTypeDef = TypedDict(
-    "_OptionalInputTypeDef",
-    {
-        "InputProcessingConfiguration": "InputProcessingConfigurationTypeDef",
-        "KinesisStreamsInput": "KinesisStreamsInputTypeDef",
-        "KinesisFirehoseInput": "KinesisFirehoseInputTypeDef",
-        "InputParallelism": "InputParallelismTypeDef",
+        "Mapping": str,
     },
     total=False,
 )
 
 
-class InputTypeDef(_RequiredInputTypeDef, _OptionalInputTypeDef):
+class RecordColumnTypeDef(_RequiredRecordColumnTypeDef, _OptionalRecordColumnTypeDef):
     pass
 
 
-_RequiredInputUpdateTypeDef = TypedDict(
-    "_RequiredInputUpdateTypeDef",
-    {
-        "InputId": str,
-    },
-)
-_OptionalInputUpdateTypeDef = TypedDict(
-    "_OptionalInputUpdateTypeDef",
-    {
-        "NamePrefixUpdate": str,
-        "InputProcessingConfigurationUpdate": "InputProcessingConfigurationUpdateTypeDef",
-        "KinesisStreamsInputUpdate": "KinesisStreamsInputUpdateTypeDef",
-        "KinesisFirehoseInputUpdate": "KinesisFirehoseInputUpdateTypeDef",
-        "InputSchemaUpdate": "InputSchemaUpdateTypeDef",
-        "InputParallelismUpdate": "InputParallelismUpdateTypeDef",
-    },
-    total=False,
-)
-
-
-class InputUpdateTypeDef(_RequiredInputUpdateTypeDef, _OptionalInputUpdateTypeDef):
-    pass
-
-
-JSONMappingParametersTypeDef = TypedDict(
-    "JSONMappingParametersTypeDef",
-    {
-        "RecordRowPath": str,
-    },
-)
-
-KinesisFirehoseInputDescriptionTypeDef = TypedDict(
-    "KinesisFirehoseInputDescriptionTypeDef",
+KinesisFirehoseInputTypeDef = TypedDict(
+    "KinesisFirehoseInputTypeDef",
     {
         "ResourceARN": str,
         "RoleARN": str,
     },
-    total=False,
 )
 
-KinesisFirehoseInputTypeDef = TypedDict(
-    "KinesisFirehoseInputTypeDef",
+KinesisStreamsInputTypeDef = TypedDict(
+    "KinesisStreamsInputTypeDef",
     {
         "ResourceARN": str,
         "RoleARN": str,
@@ -573,6 +385,22 @@ KinesisFirehoseInputUpdateTypeDef = TypedDict(
     total=False,
 )
 
+KinesisStreamsInputUpdateTypeDef = TypedDict(
+    "KinesisStreamsInputUpdateTypeDef",
+    {
+        "ResourceARNUpdate": str,
+        "RoleARNUpdate": str,
+    },
+    total=False,
+)
+
+JSONMappingParametersTypeDef = TypedDict(
+    "JSONMappingParametersTypeDef",
+    {
+        "RecordRowPath": str,
+    },
+)
+
 KinesisFirehoseOutputDescriptionTypeDef = TypedDict(
     "KinesisFirehoseOutputDescriptionTypeDef",
     {
@@ -599,32 +427,6 @@ KinesisFirehoseOutputUpdateTypeDef = TypedDict(
     total=False,
 )
 
-KinesisStreamsInputDescriptionTypeDef = TypedDict(
-    "KinesisStreamsInputDescriptionTypeDef",
-    {
-        "ResourceARN": str,
-        "RoleARN": str,
-    },
-    total=False,
-)
-
-KinesisStreamsInputTypeDef = TypedDict(
-    "KinesisStreamsInputTypeDef",
-    {
-        "ResourceARN": str,
-        "RoleARN": str,
-    },
-)
-
-KinesisStreamsInputUpdateTypeDef = TypedDict(
-    "KinesisStreamsInputUpdateTypeDef",
-    {
-        "ResourceARNUpdate": str,
-        "RoleARNUpdate": str,
-    },
-    total=False,
-)
-
 KinesisStreamsOutputDescriptionTypeDef = TypedDict(
     "KinesisStreamsOutputDescriptionTypeDef",
     {
@@ -686,15 +488,6 @@ ListApplicationsRequestRequestTypeDef = TypedDict(
     total=False,
 )
 
-ListApplicationsResponseTypeDef = TypedDict(
-    "ListApplicationsResponseTypeDef",
-    {
-        "ApplicationSummaries": List["ApplicationSummaryTypeDef"],
-        "HasMoreApplications": bool,
-        "ResponseMetadata": "ResponseMetadataTypeDef",
-    },
-)
-
 ListTagsForResourceRequestRequestTypeDef = TypedDict(
     "ListTagsForResourceRequestRequestTypeDef",
     {
@@ -702,208 +495,6 @@ ListTagsForResourceRequestRequestTypeDef = TypedDict(
     },
 )
 
-ListTagsForResourceResponseTypeDef = TypedDict(
-    "ListTagsForResourceResponseTypeDef",
-    {
-        "Tags": List["TagTypeDef"],
-        "ResponseMetadata": "ResponseMetadataTypeDef",
-    },
-)
-
-MappingParametersTypeDef = TypedDict(
-    "MappingParametersTypeDef",
-    {
-        "JSONMappingParameters": "JSONMappingParametersTypeDef",
-        "CSVMappingParameters": "CSVMappingParametersTypeDef",
-    },
-    total=False,
-)
-
-OutputDescriptionTypeDef = TypedDict(
-    "OutputDescriptionTypeDef",
-    {
-        "OutputId": str,
-        "Name": str,
-        "KinesisStreamsOutputDescription": "KinesisStreamsOutputDescriptionTypeDef",
-        "KinesisFirehoseOutputDescription": "KinesisFirehoseOutputDescriptionTypeDef",
-        "LambdaOutputDescription": "LambdaOutputDescriptionTypeDef",
-        "DestinationSchema": "DestinationSchemaTypeDef",
-    },
-    total=False,
-)
-
-_RequiredOutputTypeDef = TypedDict(
-    "_RequiredOutputTypeDef",
-    {
-        "Name": str,
-        "DestinationSchema": "DestinationSchemaTypeDef",
-    },
-)
-_OptionalOutputTypeDef = TypedDict(
-    "_OptionalOutputTypeDef",
-    {
-        "KinesisStreamsOutput": "KinesisStreamsOutputTypeDef",
-        "KinesisFirehoseOutput": "KinesisFirehoseOutputTypeDef",
-        "LambdaOutput": "LambdaOutputTypeDef",
-    },
-    total=False,
-)
-
-
-class OutputTypeDef(_RequiredOutputTypeDef, _OptionalOutputTypeDef):
-    pass
-
-
-_RequiredOutputUpdateTypeDef = TypedDict(
-    "_RequiredOutputUpdateTypeDef",
-    {
-        "OutputId": str,
-    },
-)
-_OptionalOutputUpdateTypeDef = TypedDict(
-    "_OptionalOutputUpdateTypeDef",
-    {
-        "NameUpdate": str,
-        "KinesisStreamsOutputUpdate": "KinesisStreamsOutputUpdateTypeDef",
-        "KinesisFirehoseOutputUpdate": "KinesisFirehoseOutputUpdateTypeDef",
-        "LambdaOutputUpdate": "LambdaOutputUpdateTypeDef",
-        "DestinationSchemaUpdate": "DestinationSchemaTypeDef",
-    },
-    total=False,
-)
-
-
-class OutputUpdateTypeDef(_RequiredOutputUpdateTypeDef, _OptionalOutputUpdateTypeDef):
-    pass
-
-
-_RequiredRecordColumnTypeDef = TypedDict(
-    "_RequiredRecordColumnTypeDef",
-    {
-        "Name": str,
-        "SqlType": str,
-    },
-)
-_OptionalRecordColumnTypeDef = TypedDict(
-    "_OptionalRecordColumnTypeDef",
-    {
-        "Mapping": str,
-    },
-    total=False,
-)
-
-
-class RecordColumnTypeDef(_RequiredRecordColumnTypeDef, _OptionalRecordColumnTypeDef):
-    pass
-
-
-_RequiredRecordFormatTypeDef = TypedDict(
-    "_RequiredRecordFormatTypeDef",
-    {
-        "RecordFormatType": RecordFormatTypeType,
-    },
-)
-_OptionalRecordFormatTypeDef = TypedDict(
-    "_OptionalRecordFormatTypeDef",
-    {
-        "MappingParameters": "MappingParametersTypeDef",
-    },
-    total=False,
-)
-
-
-class RecordFormatTypeDef(_RequiredRecordFormatTypeDef, _OptionalRecordFormatTypeDef):
-    pass
-
-
-_RequiredReferenceDataSourceDescriptionTypeDef = TypedDict(
-    "_RequiredReferenceDataSourceDescriptionTypeDef",
-    {
-        "ReferenceId": str,
-        "TableName": str,
-        "S3ReferenceDataSourceDescription": "S3ReferenceDataSourceDescriptionTypeDef",
-    },
-)
-_OptionalReferenceDataSourceDescriptionTypeDef = TypedDict(
-    "_OptionalReferenceDataSourceDescriptionTypeDef",
-    {
-        "ReferenceSchema": "SourceSchemaTypeDef",
-    },
-    total=False,
-)
-
-
-class ReferenceDataSourceDescriptionTypeDef(
-    _RequiredReferenceDataSourceDescriptionTypeDef, _OptionalReferenceDataSourceDescriptionTypeDef
-):
-    pass
-
-
-_RequiredReferenceDataSourceTypeDef = TypedDict(
-    "_RequiredReferenceDataSourceTypeDef",
-    {
-        "TableName": str,
-        "ReferenceSchema": "SourceSchemaTypeDef",
-    },
-)
-_OptionalReferenceDataSourceTypeDef = TypedDict(
-    "_OptionalReferenceDataSourceTypeDef",
-    {
-        "S3ReferenceDataSource": "S3ReferenceDataSourceTypeDef",
-    },
-    total=False,
-)
-
-
-class ReferenceDataSourceTypeDef(
-    _RequiredReferenceDataSourceTypeDef, _OptionalReferenceDataSourceTypeDef
-):
-    pass
-
-
-_RequiredReferenceDataSourceUpdateTypeDef = TypedDict(
-    "_RequiredReferenceDataSourceUpdateTypeDef",
-    {
-        "ReferenceId": str,
-    },
-)
-_OptionalReferenceDataSourceUpdateTypeDef = TypedDict(
-    "_OptionalReferenceDataSourceUpdateTypeDef",
-    {
-        "TableNameUpdate": str,
-        "S3ReferenceDataSourceUpdate": "S3ReferenceDataSourceUpdateTypeDef",
-        "ReferenceSchemaUpdate": "SourceSchemaTypeDef",
-    },
-    total=False,
-)
-
-
-class ReferenceDataSourceUpdateTypeDef(
-    _RequiredReferenceDataSourceUpdateTypeDef, _OptionalReferenceDataSourceUpdateTypeDef
-):
-    pass
-
-
-ResponseMetadataTypeDef = TypedDict(
-    "ResponseMetadataTypeDef",
-    {
-        "RequestId": str,
-        "HostId": str,
-        "HTTPStatusCode": int,
-        "HTTPHeaders": Dict[str, str],
-        "RetryAttempts": int,
-    },
-)
-
-S3ConfigurationTypeDef = TypedDict(
-    "S3ConfigurationTypeDef",
-    {
-        "RoleARN": str,
-        "BucketARN": str,
-        "FileKey": str,
-    },
-)
-
 S3ReferenceDataSourceDescriptionTypeDef = TypedDict(
     "S3ReferenceDataSourceDescriptionTypeDef",
     {
@@ -932,11 +523,233 @@ S3ReferenceDataSourceUpdateTypeDef = TypedDict(
     total=False,
 )
 
+StopApplicationRequestRequestTypeDef = TypedDict(
+    "StopApplicationRequestRequestTypeDef",
+    {
+        "ApplicationName": str,
+    },
+)
+
+UntagResourceRequestRequestTypeDef = TypedDict(
+    "UntagResourceRequestRequestTypeDef",
+    {
+        "ResourceARN": str,
+        "TagKeys": Sequence[str],
+    },
+)
+
+AddApplicationCloudWatchLoggingOptionRequestRequestTypeDef = TypedDict(
+    "AddApplicationCloudWatchLoggingOptionRequestRequestTypeDef",
+    {
+        "ApplicationName": str,
+        "CurrentApplicationVersionId": int,
+        "CloudWatchLoggingOption": CloudWatchLoggingOptionTypeDef,
+    },
+)
+
+TagResourceRequestRequestTypeDef = TypedDict(
+    "TagResourceRequestRequestTypeDef",
+    {
+        "ResourceARN": str,
+        "Tags": Sequence[TagTypeDef],
+    },
+)
+
+CreateApplicationResponseTypeDef = TypedDict(
+    "CreateApplicationResponseTypeDef",
+    {
+        "ApplicationSummary": ApplicationSummaryTypeDef,
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
+
+ListApplicationsResponseTypeDef = TypedDict(
+    "ListApplicationsResponseTypeDef",
+    {
+        "ApplicationSummaries": List[ApplicationSummaryTypeDef],
+        "HasMoreApplications": bool,
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
+
+ListTagsForResourceResponseTypeDef = TypedDict(
+    "ListTagsForResourceResponseTypeDef",
+    {
+        "Tags": List[TagTypeDef],
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
+
+InputConfigurationTypeDef = TypedDict(
+    "InputConfigurationTypeDef",
+    {
+        "Id": str,
+        "InputStartingPositionConfiguration": InputStartingPositionConfigurationTypeDef,
+    },
+)
+
+InputProcessingConfigurationDescriptionTypeDef = TypedDict(
+    "InputProcessingConfigurationDescriptionTypeDef",
+    {
+        "InputLambdaProcessorDescription": InputLambdaProcessorDescriptionTypeDef,
+    },
+    total=False,
+)
+
+InputProcessingConfigurationTypeDef = TypedDict(
+    "InputProcessingConfigurationTypeDef",
+    {
+        "InputLambdaProcessor": InputLambdaProcessorTypeDef,
+    },
+)
+
+InputProcessingConfigurationUpdateTypeDef = TypedDict(
+    "InputProcessingConfigurationUpdateTypeDef",
+    {
+        "InputLambdaProcessorUpdate": InputLambdaProcessorUpdateTypeDef,
+    },
+)
+
+MappingParametersTypeDef = TypedDict(
+    "MappingParametersTypeDef",
+    {
+        "JSONMappingParameters": JSONMappingParametersTypeDef,
+        "CSVMappingParameters": CSVMappingParametersTypeDef,
+    },
+    total=False,
+)
+
+OutputDescriptionTypeDef = TypedDict(
+    "OutputDescriptionTypeDef",
+    {
+        "OutputId": str,
+        "Name": str,
+        "KinesisStreamsOutputDescription": KinesisStreamsOutputDescriptionTypeDef,
+        "KinesisFirehoseOutputDescription": KinesisFirehoseOutputDescriptionTypeDef,
+        "LambdaOutputDescription": LambdaOutputDescriptionTypeDef,
+        "DestinationSchema": DestinationSchemaTypeDef,
+    },
+    total=False,
+)
+
+_RequiredOutputTypeDef = TypedDict(
+    "_RequiredOutputTypeDef",
+    {
+        "Name": str,
+        "DestinationSchema": DestinationSchemaTypeDef,
+    },
+)
+_OptionalOutputTypeDef = TypedDict(
+    "_OptionalOutputTypeDef",
+    {
+        "KinesisStreamsOutput": KinesisStreamsOutputTypeDef,
+        "KinesisFirehoseOutput": KinesisFirehoseOutputTypeDef,
+        "LambdaOutput": LambdaOutputTypeDef,
+    },
+    total=False,
+)
+
+
+class OutputTypeDef(_RequiredOutputTypeDef, _OptionalOutputTypeDef):
+    pass
+
+
+_RequiredOutputUpdateTypeDef = TypedDict(
+    "_RequiredOutputUpdateTypeDef",
+    {
+        "OutputId": str,
+    },
+)
+_OptionalOutputUpdateTypeDef = TypedDict(
+    "_OptionalOutputUpdateTypeDef",
+    {
+        "NameUpdate": str,
+        "KinesisStreamsOutputUpdate": KinesisStreamsOutputUpdateTypeDef,
+        "KinesisFirehoseOutputUpdate": KinesisFirehoseOutputUpdateTypeDef,
+        "LambdaOutputUpdate": LambdaOutputUpdateTypeDef,
+        "DestinationSchemaUpdate": DestinationSchemaTypeDef,
+    },
+    total=False,
+)
+
+
+class OutputUpdateTypeDef(_RequiredOutputUpdateTypeDef, _OptionalOutputUpdateTypeDef):
+    pass
+
+
+StartApplicationRequestRequestTypeDef = TypedDict(
+    "StartApplicationRequestRequestTypeDef",
+    {
+        "ApplicationName": str,
+        "InputConfigurations": Sequence[InputConfigurationTypeDef],
+    },
+)
+
+AddApplicationInputProcessingConfigurationRequestRequestTypeDef = TypedDict(
+    "AddApplicationInputProcessingConfigurationRequestRequestTypeDef",
+    {
+        "ApplicationName": str,
+        "CurrentApplicationVersionId": int,
+        "InputId": str,
+        "InputProcessingConfiguration": InputProcessingConfigurationTypeDef,
+    },
+)
+
+DiscoverInputSchemaRequestRequestTypeDef = TypedDict(
+    "DiscoverInputSchemaRequestRequestTypeDef",
+    {
+        "ResourceARN": str,
+        "RoleARN": str,
+        "InputStartingPositionConfiguration": InputStartingPositionConfigurationTypeDef,
+        "S3Configuration": S3ConfigurationTypeDef,
+        "InputProcessingConfiguration": InputProcessingConfigurationTypeDef,
+    },
+    total=False,
+)
+
+_RequiredRecordFormatTypeDef = TypedDict(
+    "_RequiredRecordFormatTypeDef",
+    {
+        "RecordFormatType": RecordFormatTypeType,
+    },
+)
+_OptionalRecordFormatTypeDef = TypedDict(
+    "_OptionalRecordFormatTypeDef",
+    {
+        "MappingParameters": MappingParametersTypeDef,
+    },
+    total=False,
+)
+
+
+class RecordFormatTypeDef(_RequiredRecordFormatTypeDef, _OptionalRecordFormatTypeDef):
+    pass
+
+
+AddApplicationOutputRequestRequestTypeDef = TypedDict(
+    "AddApplicationOutputRequestRequestTypeDef",
+    {
+        "ApplicationName": str,
+        "CurrentApplicationVersionId": int,
+        "Output": OutputTypeDef,
+    },
+)
+
+InputSchemaUpdateTypeDef = TypedDict(
+    "InputSchemaUpdateTypeDef",
+    {
+        "RecordFormatUpdate": RecordFormatTypeDef,
+        "RecordEncodingUpdate": str,
+        "RecordColumnUpdates": Sequence[RecordColumnTypeDef],
+    },
+    total=False,
+)
+
 _RequiredSourceSchemaTypeDef = TypedDict(
     "_RequiredSourceSchemaTypeDef",
     {
-        "RecordFormat": "RecordFormatTypeDef",
-        "RecordColumns": Sequence["RecordColumnTypeDef"],
+        "RecordFormat": RecordFormatTypeDef,
+        "RecordColumns": Sequence[RecordColumnTypeDef],
     },
 )
 _OptionalSourceSchemaTypeDef = TypedDict(
@@ -952,53 +765,240 @@ class SourceSchemaTypeDef(_RequiredSourceSchemaTypeDef, _OptionalSourceSchemaTyp
     pass
 
 
-StartApplicationRequestRequestTypeDef = TypedDict(
-    "StartApplicationRequestRequestTypeDef",
+_RequiredInputUpdateTypeDef = TypedDict(
+    "_RequiredInputUpdateTypeDef",
     {
-        "ApplicationName": str,
-        "InputConfigurations": Sequence["InputConfigurationTypeDef"],
+        "InputId": str,
     },
 )
-
-StopApplicationRequestRequestTypeDef = TypedDict(
-    "StopApplicationRequestRequestTypeDef",
+_OptionalInputUpdateTypeDef = TypedDict(
+    "_OptionalInputUpdateTypeDef",
     {
-        "ApplicationName": str,
-    },
-)
-
-TagResourceRequestRequestTypeDef = TypedDict(
-    "TagResourceRequestRequestTypeDef",
-    {
-        "ResourceARN": str,
-        "Tags": Sequence["TagTypeDef"],
-    },
-)
-
-_RequiredTagTypeDef = TypedDict(
-    "_RequiredTagTypeDef",
-    {
-        "Key": str,
-    },
-)
-_OptionalTagTypeDef = TypedDict(
-    "_OptionalTagTypeDef",
-    {
-        "Value": str,
+        "NamePrefixUpdate": str,
+        "InputProcessingConfigurationUpdate": InputProcessingConfigurationUpdateTypeDef,
+        "KinesisStreamsInputUpdate": KinesisStreamsInputUpdateTypeDef,
+        "KinesisFirehoseInputUpdate": KinesisFirehoseInputUpdateTypeDef,
+        "InputSchemaUpdate": InputSchemaUpdateTypeDef,
+        "InputParallelismUpdate": InputParallelismUpdateTypeDef,
     },
     total=False,
 )
 
 
-class TagTypeDef(_RequiredTagTypeDef, _OptionalTagTypeDef):
+class InputUpdateTypeDef(_RequiredInputUpdateTypeDef, _OptionalInputUpdateTypeDef):
     pass
 
 
-UntagResourceRequestRequestTypeDef = TypedDict(
-    "UntagResourceRequestRequestTypeDef",
+DiscoverInputSchemaResponseTypeDef = TypedDict(
+    "DiscoverInputSchemaResponseTypeDef",
     {
-        "ResourceARN": str,
-        "TagKeys": Sequence[str],
+        "InputSchema": SourceSchemaTypeDef,
+        "ParsedInputRecords": List[List[str]],
+        "ProcessedInputRecords": List[str],
+        "RawInputRecords": List[str],
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
+
+InputDescriptionTypeDef = TypedDict(
+    "InputDescriptionTypeDef",
+    {
+        "InputId": str,
+        "NamePrefix": str,
+        "InAppStreamNames": List[str],
+        "InputProcessingConfigurationDescription": InputProcessingConfigurationDescriptionTypeDef,
+        "KinesisStreamsInputDescription": KinesisStreamsInputDescriptionTypeDef,
+        "KinesisFirehoseInputDescription": KinesisFirehoseInputDescriptionTypeDef,
+        "InputSchema": SourceSchemaTypeDef,
+        "InputParallelism": InputParallelismTypeDef,
+        "InputStartingPositionConfiguration": InputStartingPositionConfigurationTypeDef,
+    },
+    total=False,
+)
+
+_RequiredInputTypeDef = TypedDict(
+    "_RequiredInputTypeDef",
+    {
+        "NamePrefix": str,
+        "InputSchema": SourceSchemaTypeDef,
+    },
+)
+_OptionalInputTypeDef = TypedDict(
+    "_OptionalInputTypeDef",
+    {
+        "InputProcessingConfiguration": InputProcessingConfigurationTypeDef,
+        "KinesisStreamsInput": KinesisStreamsInputTypeDef,
+        "KinesisFirehoseInput": KinesisFirehoseInputTypeDef,
+        "InputParallelism": InputParallelismTypeDef,
+    },
+    total=False,
+)
+
+
+class InputTypeDef(_RequiredInputTypeDef, _OptionalInputTypeDef):
+    pass
+
+
+_RequiredReferenceDataSourceDescriptionTypeDef = TypedDict(
+    "_RequiredReferenceDataSourceDescriptionTypeDef",
+    {
+        "ReferenceId": str,
+        "TableName": str,
+        "S3ReferenceDataSourceDescription": S3ReferenceDataSourceDescriptionTypeDef,
+    },
+)
+_OptionalReferenceDataSourceDescriptionTypeDef = TypedDict(
+    "_OptionalReferenceDataSourceDescriptionTypeDef",
+    {
+        "ReferenceSchema": SourceSchemaTypeDef,
+    },
+    total=False,
+)
+
+
+class ReferenceDataSourceDescriptionTypeDef(
+    _RequiredReferenceDataSourceDescriptionTypeDef, _OptionalReferenceDataSourceDescriptionTypeDef
+):
+    pass
+
+
+_RequiredReferenceDataSourceTypeDef = TypedDict(
+    "_RequiredReferenceDataSourceTypeDef",
+    {
+        "TableName": str,
+        "ReferenceSchema": SourceSchemaTypeDef,
+    },
+)
+_OptionalReferenceDataSourceTypeDef = TypedDict(
+    "_OptionalReferenceDataSourceTypeDef",
+    {
+        "S3ReferenceDataSource": S3ReferenceDataSourceTypeDef,
+    },
+    total=False,
+)
+
+
+class ReferenceDataSourceTypeDef(
+    _RequiredReferenceDataSourceTypeDef, _OptionalReferenceDataSourceTypeDef
+):
+    pass
+
+
+_RequiredReferenceDataSourceUpdateTypeDef = TypedDict(
+    "_RequiredReferenceDataSourceUpdateTypeDef",
+    {
+        "ReferenceId": str,
+    },
+)
+_OptionalReferenceDataSourceUpdateTypeDef = TypedDict(
+    "_OptionalReferenceDataSourceUpdateTypeDef",
+    {
+        "TableNameUpdate": str,
+        "S3ReferenceDataSourceUpdate": S3ReferenceDataSourceUpdateTypeDef,
+        "ReferenceSchemaUpdate": SourceSchemaTypeDef,
+    },
+    total=False,
+)
+
+
+class ReferenceDataSourceUpdateTypeDef(
+    _RequiredReferenceDataSourceUpdateTypeDef, _OptionalReferenceDataSourceUpdateTypeDef
+):
+    pass
+
+
+AddApplicationInputRequestRequestTypeDef = TypedDict(
+    "AddApplicationInputRequestRequestTypeDef",
+    {
+        "ApplicationName": str,
+        "CurrentApplicationVersionId": int,
+        "Input": InputTypeDef,
+    },
+)
+
+_RequiredCreateApplicationRequestRequestTypeDef = TypedDict(
+    "_RequiredCreateApplicationRequestRequestTypeDef",
+    {
+        "ApplicationName": str,
+    },
+)
+_OptionalCreateApplicationRequestRequestTypeDef = TypedDict(
+    "_OptionalCreateApplicationRequestRequestTypeDef",
+    {
+        "ApplicationDescription": str,
+        "Inputs": Sequence[InputTypeDef],
+        "Outputs": Sequence[OutputTypeDef],
+        "CloudWatchLoggingOptions": Sequence[CloudWatchLoggingOptionTypeDef],
+        "ApplicationCode": str,
+        "Tags": Sequence[TagTypeDef],
+    },
+    total=False,
+)
+
+
+class CreateApplicationRequestRequestTypeDef(
+    _RequiredCreateApplicationRequestRequestTypeDef, _OptionalCreateApplicationRequestRequestTypeDef
+):
+    pass
+
+
+_RequiredApplicationDetailTypeDef = TypedDict(
+    "_RequiredApplicationDetailTypeDef",
+    {
+        "ApplicationName": str,
+        "ApplicationARN": str,
+        "ApplicationStatus": ApplicationStatusType,
+        "ApplicationVersionId": int,
+    },
+)
+_OptionalApplicationDetailTypeDef = TypedDict(
+    "_OptionalApplicationDetailTypeDef",
+    {
+        "ApplicationDescription": str,
+        "CreateTimestamp": datetime,
+        "LastUpdateTimestamp": datetime,
+        "InputDescriptions": List[InputDescriptionTypeDef],
+        "OutputDescriptions": List[OutputDescriptionTypeDef],
+        "ReferenceDataSourceDescriptions": List[ReferenceDataSourceDescriptionTypeDef],
+        "CloudWatchLoggingOptionDescriptions": List[CloudWatchLoggingOptionDescriptionTypeDef],
+        "ApplicationCode": str,
+    },
+    total=False,
+)
+
+
+class ApplicationDetailTypeDef(
+    _RequiredApplicationDetailTypeDef, _OptionalApplicationDetailTypeDef
+):
+    pass
+
+
+AddApplicationReferenceDataSourceRequestRequestTypeDef = TypedDict(
+    "AddApplicationReferenceDataSourceRequestRequestTypeDef",
+    {
+        "ApplicationName": str,
+        "CurrentApplicationVersionId": int,
+        "ReferenceDataSource": ReferenceDataSourceTypeDef,
+    },
+)
+
+ApplicationUpdateTypeDef = TypedDict(
+    "ApplicationUpdateTypeDef",
+    {
+        "InputUpdates": Sequence[InputUpdateTypeDef],
+        "ApplicationCodeUpdate": str,
+        "OutputUpdates": Sequence[OutputUpdateTypeDef],
+        "ReferenceDataSourceUpdates": Sequence[ReferenceDataSourceUpdateTypeDef],
+        "CloudWatchLoggingOptionUpdates": Sequence[CloudWatchLoggingOptionUpdateTypeDef],
+    },
+    total=False,
+)
+
+DescribeApplicationResponseTypeDef = TypedDict(
+    "DescribeApplicationResponseTypeDef",
+    {
+        "ApplicationDetail": ApplicationDetailTypeDef,
+        "ResponseMetadata": ResponseMetadataTypeDef,
     },
 )
 
@@ -1007,6 +1007,6 @@ UpdateApplicationRequestRequestTypeDef = TypedDict(
     {
         "ApplicationName": str,
         "CurrentApplicationVersionId": int,
-        "ApplicationUpdate": "ApplicationUpdateTypeDef",
+        "ApplicationUpdate": ApplicationUpdateTypeDef,
     },
 )
